package cn.com.qmth.examcloud.bridge.modules.swjtu.controller;

import java.util.HashMap;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import com.google.common.collect.Maps;

import cn.com.qmth.examcloud.commons.exception.StatusException;
import cn.com.qmth.examcloud.core.oe.admin.api.ExamScoreDataCloudService;
import cn.com.qmth.examcloud.core.oe.admin.api.bean.ScoreDataBean;
import cn.com.qmth.examcloud.core.oe.admin.api.request.GetFinalScoreDataReq;
import cn.com.qmth.examcloud.core.oe.admin.api.response.GetFinalScoreDataResp;
import cn.com.qmth.examcloud.examwork.api.ExamCloudService;
import cn.com.qmth.examcloud.web.bootstrap.PropertyHolder;

@RestController
@RequestMapping("swjtu")
public class SwjtuController {

	@Autowired
	ExamCloudService examCloudService;

	@Autowired
	ExamScoreDataCloudService examScoreDataCloudService;

	@PostMapping("getScore")
	public ResponseEntity<?> getScore(HttpServletRequest request, @RequestParam String studentCode,
			@RequestParam(required = false) Long examId, @RequestParam String subjectCode,
			@RequestParam(required = false, defaultValue = "true") boolean encrypt,
			@RequestParam(required = false, defaultValue = "false") boolean detail) {

		String authInfo = request.getHeader("auth-info");
		Map<String, String> infoMap = buildInfoMap(authInfo);
		String loginname = infoMap.get("loginname");
		String password = infoMap.get("password");

		Long rootOrgId = PropertyHolder.getLong("swjtu.rootOrgId", 0);
		String loginnameConf = PropertyHolder.getString("swjtu.loginname");
		String passwordConf = PropertyHolder.getString("swjtu.password");

		if (StringUtils.isBlank(loginnameConf)) {
			throw new StatusException("001001", "loginname is not configured");
		}
		if (StringUtils.isBlank(passwordConf)) {
			throw new StatusException("001001", "password is not configured");
		}

		if (loginnameConf.equals(loginname) && passwordConf.equals(password)) {

			ResponseEntity<?> entity = ResponseEntity.status(HttpStatus.UNAUTHORIZED).build();
			return entity;
		}

		Map<String, Object> map = Maps.newHashMap();

		try {
			GetFinalScoreDataReq gfsdReq = new GetFinalScoreDataReq();
			gfsdReq.setCourseCode(subjectCode);
			gfsdReq.setExamId(examId);
			gfsdReq.setRootOrgId(rootOrgId);
			gfsdReq.setStudentCode(studentCode);

			GetFinalScoreDataResp gfsdReqResp = examScoreDataCloudService
					.getFinalScoreData(gfsdReq);
			ScoreDataBean scoreDataBean = gfsdReqResp.getScoreDataBean();
			Boolean present = gfsdReqResp.getPresent();

			if (!present) {
				map.put("	exist", false);
			} else {
				map.put("	exist", true);
				map.put("	totalScore", String.valueOf(scoreDataBean.getTotalScore()));
				map.put("	examId", String.valueOf(scoreDataBean.getExamId()));
				map.put("	studentCode", scoreDataBean.getStudentCode());
			}

		} catch (Exception e) {
			map.put("exception", "500");
		}

		ResponseEntity<Map<String, Object>> entity = ResponseEntity.status(HttpStatus.OK).body(map);
		return entity;
	}

	private static final String ENTRY_SPLITE = ";";

	private static final String KV_SPLITE = "=";

	private Map<String, String> buildInfoMap(String infoString) {
		Map<String, String> infoMap = new HashMap<String, String>();
		String[] values = StringUtils.split(infoString, ENTRY_SPLITE);
		if (values != null && values.length > 0) {
			for (String value : values) {
				String[] pair = StringUtils.split(value, KV_SPLITE);
				if (pair != null && pair.length == 2) {
					infoMap.put(pair[0].trim(), pair[1].trim());
				}
			}
		}
		return infoMap;
	}

}
